<?php
require_once 'db_config.php';

// Fetch production plan data dynamically
if ($_SERVER['REQUEST_METHOD'] === 'GET') {
    // Check if the `plan` parameter is provided
    $plan = isset($_GET['plan']) ? $_GET['plan'] : null;

    if (!$plan) {
        echo json_encode(["error" => "Production plan is required."]);
        exit;
    }

    // Prepare the query
    $stmt = $pdo->prepare("
        SELECT 
            products.product_code,
            products.old_product_code,
            products.brand,
            colors.color_code,
            colors.color_name,
            sizes.size_code,
            composition.component1,
            composition.p_component1,
            composition.component2,
            composition.p_component2,
            composition.component3,
            composition.p_component3,
            composition.region,
            products.price_floor,
            products.price_ceparator,
            products.price_decimal,
            products.currency,
            templates.template_code,
            products.ean_code
        FROM production_plans
        JOIN products ON production_plans.product_id = products.id
        JOIN colors ON products.id = colors.product_id
        JOIN sizes ON products.id = sizes.product_id
        JOIN composition ON production_plans.region_id = composition.id
        JOIN templates ON production_plans.template_id = templates.id
        WHERE production_plans.plan = :plan
    ");

    // Execute the query with the plan parameter
    $stmt->execute(['plan' => $plan]);

    // Fetch the result
    $data = $stmt->fetch();

    if ($data) {
        echo json_encode($data);
    } else {
        echo json_encode(["error" => "Production plan not found."]);
    }
}
?>
