<?php
// Start session
session_start();

// Check if user is logged in
if (!isset($_SESSION['user_id'])) {
    header("Location: user-login.php");
    exit();
}

// Database connection
$host = '127.0.0.1';
$db = 'temasa1';
$user = 'root';
$pass = '';

// Create connection
try {
    $pdo = new PDO("mysql:host=$host;dbname=$db", $user, $pass);
    $pdo->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION);
} catch (PDOException $e) {
    die("Could not connect to the database: " . $e->getMessage());
}

// Fetch user data
$user_id = $_SESSION['user_id'];
$sql = "SELECT printer_count FROM post_information WHERE id = ?";
$stmt = $pdo->prepare($sql);
$stmt->execute([$user_id]);
$user = $stmt->fetch();

$printer_count = $user['printer_count'];
?>



</html>
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Production Plan</title>
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <script src="https://code.jquery.com/jquery-3.6.0.min.js"></script>
    <style>
        .sidebar {
            position: fixed;
            top: 0;
            left: 0;
            width: 250px;
            height: 100%;
            background-color: #f8f9fa;
            padding: 15px;
            overflow-y: auto;
            box-shadow: 2px 0 5px rgba(0,0,0,0.1);
        }
        .main-content {
            margin-left: 270px; /* Adjust based on sidebar width */
            padding: 15px;
        }
        .form-label {
            font-weight: bold;
        }
    </style>
</head>
<body>

<div class="sidebar">
    <hr>
    <button class="btn btn-danger w-100 mb-3" type="button" id="clear_inputs">
        <i class="bi bi-trash"></i> Vider
    </button>
    <hr>
    <h2 class="text-center mb-4">Scanner</h2>
    <hr>
    <div class="mb-3">
        <input type="text" class="form-control" placeholder="Plan de production" id="production_plan">
    </div>
    <div class="mb-3">
        <button class="btn btn-primary w-100" type="button" id="scan_plan">
            <i class="bi bi-search"></i> Scanner
        </button>
    </div>

    <hr>

    <div class="mb-3">
        <input type="text" class="form-control" placeholder="Code Article" id="code_article">
    </div>
    <div class="mb-3">
        <input type="text" class="form-control" placeholder="Code Couleur" id="code_couleur">
    </div>
    <div class="mb-3">
        <input type="text" class="form-control" placeholder="Code Taille" id="code_taille">
    </div>
    <div class="mb-3">
        <button class="btn btn-primary w-100" type="button" id="scan_details">
            <i class="bi bi-search"></i> Scanner
        </button>
    </div>
    <hr>

    <div class="mb-3">
        <label for="copies" class="form-label">Nombre de Copies</label>
        <input type="number" class="form-control" id="copies" name="copies" value="1" required>
    </div>

    <hr>

    <div class="mb-3">
        <button class="btn btn-success w-100" type="button" id="create_label">
            <i class="bi bi-printer"></i> Imprimer
        </button>
    </div>
</div>

<!-- JavaScript -->
<script>
    const productionPlanInput = document.getElementById("production_plan");
    const scanPlanButton = document.getElementById("scan_plan");
    const copiesInput = document.getElementById("copies");
    const createLabelButton = document.getElementById("create_label");

    // Step 1: Press Enter in "Plan de Production" -> Click Scanner
    productionPlanInput.addEventListener("keypress", function (event) {
        if (event.key === "Enter" && this.value.trim() !== "") {
            event.preventDefault(); // Prevent form submission or default behavior
            scanPlanButton.click(); // Trigger the click event on the Scanner button
            scanPlanButton.focus(); // Set focus to the Scanner button
        }
    });

    // Step 2: After clicking Scanner and data is ready -> Focus on "Nombre de Copies"
    scanPlanButton.addEventListener("click", function () {
        // Simulate data being ready (you can replace this with an actual data-checking mechanism)
        setTimeout(() => {
            copiesInput.focus(); // Move focus to the "Nombre de Copies" field
        }, 500); // Simulated delay to mimic processing time
    });

    // Step 3: After inputting copies, move focus to "Imprimer"
    copiesInput.addEventListener("input", function () {
        if (this.value.trim() !== "") {
            createLabelButton.focus();
        }
    });
</script>


<div class="main-content">
    <div class="container">
        

            <form method="POST" id="label_form">
            <div class="row hidden align-items-end" id="copies_info">
                <?php if ($printer_count >= 1): ?>
            <div class="col-md-4">
                <label for="printer_r" class="form-label">Imprimante R</label>
                <select class="form-select" id="printer_r" name="printer_r" required>
                    <?php
                    $stmt = $pdo->prepare("
                        SELECT p.printer_id, pr.name 
                        FROM post_printers p
                        JOIN printers pr ON p.printer_id = pr.id
                        WHERE p.post_id = ? AND p.assignment = 'R'
                    ");
                    $stmt->execute([$user_id]);
                    $printers_r = $stmt->fetchAll(PDO::FETCH_ASSOC);
                    if (empty($printers_r)) {
                        echo '<option value="">No printers assigned</option>';
                    } else {
                        foreach ($printers_r as $printer) {
                            echo '<option value="' . $printer['printer_id'] . '">' . $printer['name'] . '</option>';
                        }
                    }
                    ?>
                </select>
            </div>
        <?php endif; ?>
        <?php if ($printer_count == 2): ?>
            <div class="col-md-4">
                <label for="printer_v" class="form-label">Imprimante V</label>
                <select class="form-select" id="printer_v" name="printer_v" required>
                    <?php
                    $stmt = $pdo->prepare("
                        SELECT p.printer_id, pr.name 
                        FROM post_printers p
                        JOIN printers pr ON p.printer_id = pr.id
                        WHERE p.post_id = ? AND p.assignment = 'V'
                    ");
                    $stmt->execute([$user_id]);
                    $printers_v = $stmt->fetchAll(PDO::FETCH_ASSOC);
                    if (empty($printers_v)) {
                        echo '<option value="">No printers assigned</option>';
                    } else {
                        foreach ($printers_v as $printer) {
                            echo '<option value="' . $printer['printer_id'] . '">' . $printer['name'] . '</option>';
                        }
                    }
                    ?>
                </select>
            </div>
        <?php endif; ?>
    
    <!-- Debugging information -->
    
    <div class="col-md-4">
        <label class="btn btn-secondary btn-sm me-2 rotate-btn" style="cursor: pointer;">
            <input type="checkbox" id="rotate_labels" autocomplete="off">
            Tourner les étiquettes
        </label>
    </div>
</div>

                <hr class="my-4">
                <div class="row hidden" id="product_info">
                    <div class="col-md-3">
                        <label for="old_product_code" class="form-label text-danger">Plan de production</label>
                        <input type="text" class="form-control text-danger" id="plan" name="plan" readonly>
                    </div>
                </div>

                <div class="row hidden" id="product_info">
                    <div class="col-md-3">
                        <label for="old_product_code" class="form-label text-danger">Ancien Code Article</label>
                        <input type="text" class="form-control text-danger" id="old_product_code" name="old_product_code" readonly>
                    </div>
                    <div class="col-md-3">
                        <label for="color_code" class="form-label text-danger">Code Couleur</label>
                        <input type="text" class="form-control text-danger" id="color_code" name="color_code" readonly>
                    </div>
                    <div class="col-md-3">
                        <label for="size_code" class="form-label text-danger">Code Taille</label>
                        <input type="text" class="form-control text-danger" id="size_code" name="size_code" readonly>
                    </div>
                </div>

                <hr class="my-4">

                <div class="row hidden" id="color_size_info">
                    <div class="col-md-3">
                        <label for="component1" class="form-label">Code Article</label>
                        <input type="text" class="form-control" id="product_code" name="product_code" readonly>
                    </div>
                    <div class="col-md-3">
                        <label for="component2" class="form-label">Marque</label>
                        <input type="text" class="form-control" id="brand" name="brand" readonly>
                    </div>
                    <div class="col-md-3">
                        <label for="component3" class="form-label">Nom Couleur</label>
                        <input type="text" class="form-control" id="color_name" name="color_name" readonly>
                    </div>
                    <div class="col-md-3">
                        <label for="product_code" class="form-label">La charge </label>
                        <input type="text" class="form-control" id="version" name="version" value="1.0" readonly>
                    </div>
                </div>
                <hr class="my-4">
                
           

                <!-- Color and Size Information -->
                <div class="row hidden" id="color_size_info">
                    <!-- Color Name -->
                    
                    <!-- Size Code -->
                    
                    <!-- Component 1 -->
                    
                </div>
    
            
    
                <div class="row hidden" id="color_size_info">
                   
                    
                    <!-- Component 1 -->
                    <div class="col-md-3">
                        <input  style="font-weight: 600;" class="form-control" id="component1" name="component1" readonly>
                        <input type="text" class="form-control" id="p_component1" name="p_component1" readonly>
                    </div>
                    <!-- Component 2 -->
                    <div class="col-md-3">
                        <input  style="font-weight: 600;"  class="form-control" id="component2" name="component2" readonly>
                        <input type="text" class="form-control" id="p_component2" name="p_component2" readonly>
                    </div>
    
                    <div class="col-md-3">
                        <input style="font-weight: 600;"  class="form-control" id="component3" name="component3" readonly>
                        <input type="text" class="form-control" id="p_component3" name="p_component3" readonly>
                    </div>
                </div>
    

                <hr class="my-4">

                <div class="row hidden" id="components_region">
                    <div class="col-md-3">
                        <label for="region" class="form-label">Region</label>
                        <input type="text" class="form-control" id="region" name="region" readonly>
                    </div>
                    <div class="col-md-3">
                        <label for="price" class="form-label">Prix .</label>
                        <input type="number" class="form-control" id="price" name="price" required>
                    </div>
                    <div class="col-md-3">
                        <label for="price_2" class="form-label">. Centimes</label>
                        <input type="number" class="form-control" id="price_2" name="price_2" required>
                    </div>
                        <div class="col-md-3">
        <label for="currency" class="form-label">Devise</label>
        <select class="form-select" id="currency" name="currency" required>
            <!-- Dynamic options will be populated here -->
        </select>
    </div>
                    </div>

                <hr class="my-4">

                <div class="row hidden" id="template_ean_code">
                    <div class="col-md-4">
                        <label for="template_code" class="form-label">Code Template R</label>
                        <input type="text" class="form-control" id="template_code" name="template_code" readonly>
                    </div>
                    <div class="col-md-4">
                        <label for="template_code_2" class="form-label">Code Template V</label>
                        <input type="text" class="form-control" id="template_code_2" name="template_code_2" readonly>
                    </div>
                    <div class="col-md-4">
                        <label for="ean_code" class="form-label">Code EAN</label>
                        <input type="text" class="form-control" id="ean_code" name="ean_code" readonly>
                    </div>
                </div>

                <hr class="my-4">

       
                <br>
                
                <hr class="my-4">
            </form>
        </div>

        <!-- create hiden to save the template path -->
         <label for="template_path" class="form-label" style="display:none"></label>
        <input style="display:none" type="text" class="form-control hidden" id="template_path" name="template_path" readonly>
        </label>
        

        <div class="container hidden" id="payload-container">
            <h3 class="text-center mb-4">Data Ready to Send to Bartender</h3>
            <p><strong>Endpoint:</strong> <span id="endpoint"></span></p>
            <pre id="payload"></pre>
        </div>
    </div>
</div>


<script src="https://cdn.jsdelivr.net/npm/sweetalert2@11.15.10/dist/sweetalert2.all.min.js"></script>

<script>
$(document).ready(function () {
    // Fetch currencies from the database and populate the dropdown
    $.ajax({
        url: 'http://localhost/temasa/get_currencies.php',
        method: 'GET',
        headers: {
            'Accept': 'application/json'
        },
        success: function(response) {
            console.log('Response from server:', response); // Log the response
            var currencies = response; // No need to parse if it's already an object
            var currencyDropdown = $('#currency');

            // Clear existing options
            currencyDropdown.empty();

            // Populate with new options
            currencies.forEach(function(currency) {
                console.log('Adding currency:', currency); // Log each currency
                var option = $('<option>', { value: currency.code, text: currency.symbol });
                if (currency.code === 'eur') {
                    option.attr('selected', 'selected');
                }
                currencyDropdown.append(option);
            });
        },
        error: function() {
            alert('Error fetching currencies.');
        }
    });

    // Handle clearing all inputs
    $('#clear_inputs').click(function() {
        $('input').val('');
        $('#copies').val('1');
    });

    // Handle scanning the production plan
    $('#scan_plan').click(function() {
        var productionPlan = $('#production_plan').val();
        $('#copies').val("1");

        if (productionPlan) {
            // Use curl to fetch the data for this production plan from the server
            $.ajax({
                url: 'http://localhost/temasa/index.php',
                method: 'GET',
                data: { plan: productionPlan },
                headers: {
                    'Accept': 'application/json'
                },
                success: function(response) {
                    var data = JSON.parse(response);
                    $('#plan').val(data.plan);
                    // Display fetched data in the fields
                    $('#product_code').val(data.product_code);
                    $('#old_product_code').val(data.old_product_code);
                    $('#color_code').val(data.color_code);
                    $('#color_name').val(data.color_name);
                    $('#size_code').val(data.size_code);
                    $('#component1').val(data.component1);
                    $('#p_component1').val(data.p_component1);
                    $('#component2').val(data.component2);
                    $('#p_component2').val(data.p_component2);
                    $('#component3').val(data.component3);
                    $('#p_component3').val(data.p_component3);
                    $('#region').val(data.region);
                    $('#price').val(data.price_floor);
                    $('#price_2').val(data.price_decimal);
                    $('#template_code').val(data.template_path);
                    $('#template_code_2').val(data.template_path);
                    $('#ean_code').val(data.ean_code);
                    $('#brand').val(data.brand);
                    $('#template_path').val(data.template_path);
                    console.log(data);

                    // check if we have 2 paths ceparated by ";"

                    if (data.template_path.includes(";")) {
                        var paths = data.template_path.split(";");
                        // make send last 13 characters of the path
                        $('#template_code').val(paths[0].slice(-13));
                        $('#template_code_2').val(paths[1].slice(-13));
                    } else {
                        $('#template_code').val(data.template_path);
                    }

                    // Show all fields and the submit button
                    $('#product_info, #color_size_info, #components_region, #region_price, #template_ean_code, #copies_info, #template_path').removeClass('hidden');
                    $('#form-container').removeClass('hidden');

                    // Add another printer selection if num_pages is 2
                    if (data.num_pages == 2) {
                        var printerSelect = `
                           `;
                        $('#copies_info').append(printerSelect);
                    }
                },
                error: function() {
                    alert('Error fetching production plan data.');
                }
            });

            console.log(productionPlan);
            console.log('Fetching data...');
        }
    });

  // Handle scanning the details
  $('#scan_details').click(function () {
    var codeArticle = $('#code_article').val();
    var codeCouleur = $('#code_couleur').val();
    var codeTaille = $('#code_taille').val();

    if (codeArticle && codeCouleur && codeTaille) {
        // Use AJAX to fetch the data for these details from the server
        $.ajax({
            url: 'http://localhost/temasa/geter.php',
            method: 'GET',
            data: {
                code_article: codeArticle,
                size_code: codeTaille,
                color_code: codeCouleur
            },
            headers: {
                'Accept': 'application/json'
            },
            success: function (response) {
                console.log('Full response received:', response);

                // Ensure the response is correctly parsed and contains data
                if (typeof response === 'string') {
                    response = JSON.parse(response); // Parse if the response is a JSON string
                }

                if (response && response.data) {
                    var data = response.data;

                    // Display fetched data in the fields
                   // $('#plan').val(data.plan || '');
                    $('#product_code').val(data.product_code || '');
                    $('#product_name').val(data.product_name || '');
                    $('#brand').val(data.brand || '');
                    $('#color_code').val(data.color_code || '');
                    $('#old_product_code').val(data.old_code_article || '');
                    $('#color_name').val(data.color_name || '');
                    $('#size_code').val(data.size_code || '');
                    $('#region').val(data.region || '');
                    $('#instructions').val(data.instructions || '');
                    $('#client_command').val(data.client_command || '');
                    $('#price').val(data.price_floor || '');
                    $('#price_2').val(data.price_decimal || '');
                    $('#template_code').val(data.template_name || '');
                    $('#p_component1').val(data.p_component1 || '');
                    $('#component1').val(data.component1 || '');
                    $('#p_component2').val(data.p_component2 || '');
                    $('#component2').val(data.component2 || '');
                    $('#p_component3').val(data.p_component3 || '');
                    $('#component3').val(data.component3 || '');
                    $('#template_path').val(data.template_path || '');
                    $('#copies').val('1');

                    console.log('Data fetched successfully:', data);

                    if (data.template_path.includes(";")) {
                        var paths = data.template_path.split(";");
                        // make send last 13 characters of the path
                        $('#template_code').val(paths[0].slice(-13));
                        $('#template_code_2').val(paths[1].slice(-13));
                    } else {
                        $('#template_code').val(data.template_path);
                    }

                    // Show all fields and the submit button
                    $('#product_info, #color_size_info, #components_region, #region_price, #template_ean_code, #copies_info, #template_path').removeClass('hidden');
                    $('#form-container').removeClass('hidden');
                } else {
                    console.log('No data found in response:', response);
                    alert('No data found.');
                }
            },
            error: function (xhr, status, error) {
                console.error('Error fetching details:', error);
                alert('Error fetching details data.');
            }
        });
    } else {
        alert('Please fill in all required fields: code_article, code_couleur, and code_taille.');
    }
});

    // Handle rotating labels button click
    $('#create_label').click(function() {
        var templatePathValue = $('#template_path').val();
        console.log('Template Path Value:', templatePathValue); // Debug: Show template path value

        // split the template path to get the template paths for each printer by ";"
        if (!templatePathValue) {
            alert('Template path is not set.');
            return;
        }

        var templatePaths = templatePathValue.split(';'); // Use the template_path field
        console.log('Template Paths:', templatePaths); // Debug: Show template paths

        var copies = $('#copies').val();
        console.log('Copies:', copies); // Debug: Show copies value

        var printers = [$('#printer_r').val()];
        var printerNames = [$('#printer_r option:selected').text()];
        if ($('#printer_v').length) {
            printers.push($('#printer_v').val());
            printerNames.push($('#printer_v option:selected').text());
        }
        console.log('Printers:', printers); // Debug: Show printers
        console.log('Printer Names:', printerNames); // Debug: Show printer names

        if (templatePaths.length < printers.length) {
            alert('The number of template paths does not match the number of printers.');
            return;
        }

        var allPayloads = [];

        printers.forEach(function(printer, index) {
            var payload = {
                "PrintBTWAction": {
                    "Document": templatePaths[index].trim(),
                    "Printer": printerNames[index],
                    "Name": "Print Document Request",
                    "Description": "This is a print document request to print a label.",
                    "SaveAfterPrint": false,
                    "QueueAndContinue": false,
                    "VerifyPrintJobIsComplete": true,
                    "ReturnPrintSummary": true,
                    "NamedDataSources": {
                        "prix": $('#price').val(),
                        "prix_2": $('#price_2').val(),
                        "currency": $('#currency').find(":selected").text(),
                        "size": $('#size_code').val(),
                        "color": $('#color_name').val(),
                        "codecolor": $('#color_code').val(),
                        "ean": $('#ean_code').val(),
                        "product_code": $('#product_code').val()
                    }
                }
            };
            console.log('Payload for printer', printer, ':', payload); // Debug: Show payload

            allPayloads.push(payload);

            // Send the request
            $.ajax({
    url: "http://localhost:5159/api/actions?KeepStatus=60m&Wait=15s&MessageCount=200&MessageSeverity=Info",
    method: "POST",
    contentType: "application/json",
    headers: {
        'Accept': 'application/json',
        'Authorization': 'Basic bW9oYW1lZDoxMjM0NTZ3YWM='
    },
    data: JSON.stringify(payload),
    success: function(response) {
        console.log('Response from server:', response);

        // Extract messages from the response
        const messages = response.Messages || [];
        const status = response.Status || 'Unknown status'; // Default to 'Unknown status' if not present 
        const formattedMessages = messages.join('\n'); // Join messages into a single string

        Swal.fire({
            title: 'Success!',
            text: formattedMessages + '\nStatus: ' + status,
            icon: 'success',
            confirmButtonText: 'OK'
        });
    },
    error: function(jqXHR, textStatus, errorThrown) {
        const response = jqXHR.responseJSON || {};
        const errorMessages = response.Messages || [];
        const formattedMessages = errorMessages.join('\n'); // Join error messages into a single string

        console.error('Error sending label data:', textStatus, errorThrown, jqXHR.responseText);

        Swal.fire({
            title: 'Error!',
            text: formattedMessages || 'Error sending label data: ' + textStatus + ' ' + errorThrown,
            icon: 'error',
            confirmButtonText: 'OK'
        });
    }
});


            // Log the request and payload
            $.ajax({
                url: "http://localhost/temasa/log_requests.php",
                method: "POST",
                data: {
                    endpoint: "http://localhost:5159/api/actions",
                    payload: JSON.stringify(payload)
                },
                success: function(response) {
                    console.log('Logged request:', response);
                },
                error: function(jqXHR, textStatus, errorThrown) {
                    console.error('Error logging request:', textStatus, errorThrown, jqXHR.responseText);
                }
            });
        });

        // Display the endpoint and all payloads
        $('#endpoint').text("http://localhost:5159/api/actions");
        $('#payload').text(JSON.stringify(allPayloads, null, 4));
        $('#payload-container').removeClass('hidden');

        // Disable the "Imprimer" button
        $('#create_label').prop('disabled', true);

        // Clear the input fields
        $('#plan').val('');
        $('#product_code').val('');
        $('#product_name').val('');
        $('#brand').val('');
        $('#color_code').val('');
        $('#old_product_code').val('');
        $('#color_name').val('');
        $('#size_code').val('');
        $('#region').val('');
        $('#instructions').val('');
        $('#client_command').val('');
        $('#price').val('');
        $('#price_2').val('');
        $('#template_code').val('');
        $('#p_component1').val('');
        $('#component1').val('');
        $('#p_component2').val('');
        $('#component2').val('');
        $('#p_component3').val('');
        $('#component3').val('');
        $('#template_path').val('');
        $('#copies').val('1');
    });

    // Enable the "Imprimer" button when a new code is scanned
    $('#scan_plan, #scan_details').click(function() {
        $('#create_label').prop('disabled', false);
    });
});
    
</script>

<!-- Bootstrap Icons -->
<link href="https://cdn.jsdelivr.net/npm/bootstrap-icons/font/bootstrap-icons.css" rel="stylesheet">
<!-- Bootstrap JS -->
<script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
</body>
</html>
