<?php
require_once 'db_config.php';

// Create connection
$conn = new mysqli($host, $user, $pass, $db);

// Check connection
if ($conn->connect_error) {
    die("Connection failed: " . $conn->connect_error);
}

if ($_SERVER['REQUEST_METHOD'] === 'GET') {
    $plan = isset($_GET['plan']) ? $_GET['plan'] : null;

    if (!$plan) {
        echo json_encode(["error" => "Production plan is required."]);
        http_response_code(400);
        exit;
    }

    $stmt = $conn->prepare("
    SELECT 
        p.code_article AS product_code,
        p.marque AS brand,
        c.color AS color_name,
        c.code_color AS color_code,
        s.code AS size_code,
        comp.name AS region,
        comp.compositions AS components,
        t.name AS template_code,
        t.num_pages AS num_pages,
        t.path AS template_path,
        p.ean_code,
        p.price_floor,
        p.old_code_article,
        p.price_ceparator,
        p.price_decimal,
        p.currency
    FROM products p
    LEFT JOIN product_color pc ON p.id = pc.product_id
    LEFT JOIN colors c ON pc.color_id = c.id
    LEFT JOIN product_size ps ON p.id = ps.product_id
    LEFT JOIN sizes s ON ps.size_id = s.id
    LEFT JOIN composition comp ON p.region_id = comp.id
    LEFT JOIN templates t ON p.template_id = t.id
    WHERE p.plan = ?
");

    if (!$stmt) {
        echo json_encode(["error" => "Failed to prepare SQL statement"]);
        exit;
    }

    $stmt->bind_param('s', $plan);
    $stmt->execute();
    $result = $stmt->get_result();
    $data = $result->fetch_assoc();

    if ($data) {
        // Parse components field
        if (!empty($data['components'])) {
            $components = explode(';', $data['components']);
            foreach ($components as $index => $component) {
                [$name, $percentage] = explode(':', $component);
                $data["component" . ($index + 1)] = trim($name);
                $data["p_component" . ($index + 1)] = trim($percentage);
            }
        }

        // Remove raw components field
        unset($data['components']);

        $response_data = [
            "plan" => $plan,
            "product_code" => $data['product_code'],
            "old_product_code" => $data['old_code_article'] ?? null,
            "brand" => $data['brand'],
            "color_code" => $data['color_code'],
            "color_name" => $data['color_name'],
            "size_code" => $data['size_code'],
            "component1" => $data['component1'] ?? null,
            "p_component1" => $data['p_component1'] ?? null,
            "component2" => $data['component2'] ?? null,
            "p_component2" => $data['p_component2'] ?? null,
            "component3" => $data['component3'] ?? null,
            "p_component3" => $data['p_component3'] ?? null,
            "region" => $data['region'],
            "price_floor" => $data['price_floor'],
            "price_ceparator" => $data['price_ceparator'],
            "price_decimal" => $data['price_decimal'],
            "currency" => $data['currency'],
            "template_code" => $data['template_code'],
            "ean_code" => $data['ean_code'],
            "num_pages" => $data['num_pages'],
            "template_path" => $data['template_path'],
            // defalut copies is 1
            "copies" => 1
        ];

        echo json_encode($response_data);
    } else {
        echo json_encode(["error" => "Production plan not found."]);
    }

    $stmt->close();
}

$conn->close();
?>
