<?php
// Enable error reporting
error_reporting(E_ALL);
ini_set('display_errors', 1);

// Start session
session_start();

// Database connection
$host = '127.0.0.1';
$db = 'temasa1';
$user = 'root';
$pass = '';

// Create connection
try {
    $pdo = new PDO("mysql:host=$host;dbname=$db", $user, $pass);
    $pdo->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION);
} catch (PDOException $e) {
    die("Could not connect to the database: " . $e->getMessage());
}

// Handle login
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $user_name = $_POST['user_name'];
    $password = $_POST['password'];

    $sql = "SELECT * FROM post_information WHERE user_name = ?";
    $stmt = $pdo->prepare($sql);
    $stmt->execute([$user_name]);
    $user = $stmt->fetch();

    if ($user && password_verify($password, $user['password'])) {
        $_SESSION['user_id'] = $user['id'];
        $_SESSION['user_name'] = $user['user_name'];
        $_SESSION['role'] = $user['role'];
        echo json_encode(['success' => true, 'role' => strtolower($user['role'])]);
    } else {
        echo json_encode(['success' => false, 'message' => 'Invalid username or password.']);
    }
    exit();
}
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="utf-8">
    <meta name="author" content="Muhamad Nauval Azhar">
    <meta name="viewport" content="width=device-width,initial-scale=1">
    <meta name="description" content="This is a login page template based on Bootstrap 5">
    <title>Bootstrap 5 Login Page</title>
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.0.0-beta2/dist/css/bootstrap.min.css" rel="stylesheet" integrity="sha384-BmbxuPwQa2lc/FVzBcNJ7UAyJxM6wuqIj61tLrc4wSX0szH/Ev+nYRRuWlolflfl" crossorigin="anonymous">
    <!-- Include SweetAlert2 library -->
    <script src="https://cdn.jsdelivr.net/npm/sweetalert2@11"></script>
    <!-- Include jQuery for AJAX -->
    <script src="https://ajax.googleapis.com/ajax/libs/jquery/3.5.1/jquery.min.js"></script>
</head>

<body>
    <section class="h-100">
        <div class="container h-100">
            <div class="row justify-content-sm-center h-100">
                <div class="col-xxl-4 col-xl-5 col-lg-5 col-md-7 col-sm-9">
                    <div class="text-center my-5">
                        <img src="https://getbootstrap.com/docs/5.0/assets/brand/bootstrap-logo.svg" alt="logo" width="100">
                    </div>
                    <div class="card shadow-lg">
                        <div class="card-body p-5">
                            <h1 class="fs-4 card-title fw-bold mb-4">Login</h1>
                            <form id="loginForm" class="needs-validation" novalidate="" autocomplete="off">
                                <div class="mb-3">
                                    <label class="mb-2 text-muted" for="user_name">Username</label>
                                    <input id="user_name" type="text" class="form-control" name="user_name" value="" required autofocus>
                                    <div class="invalid-feedback">
                                        Username is required
                                    </div>
                                </div>

                                <div class="mb-3">
                                    <div class="mb-2 w-100">
                                        <label class="text-muted" for="password">Password</label>
                                    </div>
                                    <input id="password" type="password" class="form-control" name="password" required>
                                    <div class="invalid-feedback">
                                        Password is required
                                    </div>
                                </div>

                                <div class="d-flex align-items-center">
                                    <div class="form-check">
                                        <input type="checkbox" name="remember" id="remember" class="form-check-input">
                                        <label for="remember" class="form-check-label">Remember Me</label>
                                    </div>
                                    <button type="submit" class="btn btn-primary ms-auto">
                                        Login
                                    </button>
                                </div>
                            </form>
                        </div>
                        <div class="card-footer py-3 border-0">
                            
                        </div>
                    </div>
                    <div class="text-center mt-5 text-muted">
                        Copyright &copy; 2024 &mdash; TEMASA
                    </div>
                </div>
            </div>
        </div>
    </section>

    <script>
        // Handle form submission via AJAX
        $('#loginForm').submit(function(e) {
            e.preventDefault(); // Prevent the form from submitting the usual way

            // Get form data
            var user_name = $('#user_name').val();
            var password = $('#password').val();

            // Perform AJAX request
            $.ajax({
                url: 'user-login.php', // Make sure the user-login.php file is set up correctly
                type: 'POST',
                data: {
                    user_name: user_name,
                    password: password
                },
                success: function(response) {
                    // Ensure response is parsed correctly and check the structure
                    if (typeof response === 'string') {
                        response = JSON.parse(response); // If the response is a string, parse it
                    }
                    console.log(response); // Log the full response to see what is returned

                    // Check the 'success' field explicitly
                    if (response.success) {
                        // If login is successful, show a success message
                        Swal.fire({
                            icon: 'success',
                            title: 'Login Successful!',
                            text: 'You have successfully logged in.',
                        }).then(() => {
                            // Redirect based on the role after success
                            if (response.role === 'admin') {
                                window.location.href = 'dashboard_admin.php';
                            } else if (response.role === 'manager') {
                                window.location.href = 'dashboard_manager.php';
                            } else {
                                window.location.href = 'home.php';
                            }
                        });
                    } else {
                        // If login fails, show an error message
                        Swal.fire({
                            icon: 'error',
                            title: 'Oops...',
                            text: response.message || 'An error occurred',
                        });
                    }
                },
                error: function(xhr, status, error) {
                    // Log the error details for debugging
                    console.error('AJAX Error:', error);
                    Swal.fire({
                        icon: 'error',
                        title: 'Oops...',
                        text: 'An error occurred while processing your request.',
                    });
                }
            });
        });
    </script>
</body>
</html>